<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>404: This page could not be found</title>
    <style>
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        html, body {
            height: 100%;
            font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', 'Roboto', 'Oxygen', 'Ubuntu', 'Cantarell', 'Fira Sans', 'Droid Sans', 'Helvetica Neue', sans-serif;
            -webkit-font-smoothing: antialiased;
            -moz-osx-font-smoothing: grayscale;
        }

        body {
            color: #000;
            background: #fff;
            display: flex;
            align-items: center;
            justify-content: center;
        }

        .error {
            display: flex;
            align-items: center;
            justify-content: center;
            height: 100vh;
        }

        .error-content {
            display: flex;
            align-items: center;
            gap: 20px;
        }

        .error-code {
            font-size: 24px;
            font-weight: 500;
            padding-right: 23px;
            border-right: 1px solid rgba(0, 0, 0, 0.3);
            line-height: 49px;
            height: 49px;
        }

        .error-message {
            font-size: 14px;
            font-weight: 400;
            line-height: 49px;
            height: 49px;
        }

        .error-message h2 {
            font-size: 14px;
            font-weight: 400;
            display: inline;
        }

        /* Dark mode */
        @media (prefers-color-scheme: dark) {
            body {
                color: #fff;
                background: #000;
            }

            .error-code {
                border-right-color: rgba(255, 255, 255, 0.3);
            }
        }
    </style>
</head>
<body>
    <div class="error">
        <div class="error-content">
            <div class="error-code">404</div>
            <div class="error-message">
                <h2>This page could not be found.</h2>
            </div>
        </div>
    </div>
</body>
</html>
